<?php
/**
 * Admin order rejected email.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/admin-order-rejected.php
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see    https://docs.woocommerce.com/document/template-structure/
 * @author  wbcom
 * @package WooCommerce/Templates/Emails/HTML
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$admin_data = get_user_by( 'email', get_option( 'admin_email' ) );
$admin_name = $admin_data->data->display_name;

/**
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email ); ?>

<p>
<?php
/* translators: %s: Recipient Name. */
printf( esc_html__( 'Dear %s,', 'woo-sell-services' ), esc_attr( $admin_name ) );
?>
</p>
<p>
<?php
/* translators: %1$1s: Order Number, %2$2s: Item id, %3$3s: Starting bold tag, %4$4s: Product name, %5$5s: Ending bold tag, %6$6s: Recipient name. */
printf( esc_html__( 'You have received rejection of final delivery of an order ( #%1$1s - %2$2s), %3$3s %4$4s %5$5s from %6$6s', 'woo-sell-services' ), esc_attr( $order->get_order_number() ), esc_attr( $item_id ), '<b><i>', esc_attr( $product->get_name() ), '</i></b>', esc_attr( $order->get_formatted_billing_full_name() ) );
?>
</p>

<p><?php esc_html_e( 'The order is as follows:', 'woo-sell-services' ); ?></p>

<?php

/**
 * @hooked WC_Emails::order_details() Shows the order details table.
 * @hooked WC_Structured_Data::generate_order_data() Generates structured data.
 * @hooked WC_Structured_Data::output_structured_data() Outputs structured data.
 * @since 2.5.0
 */
do_action( 'woocommerce_email_order_details', $order, $sent_to_admin, $plain_text, $email );

$wbwss_general_settings = get_option( 'wbwss_general_settings', true );
$service_page_url       = home_url( 'service' );
if ( isset( $wbwss_general_settings['woo_sell_service_order_page'] ) && '' != $wbwss_general_settings['woo_sell_service_order_page'] ) {
	$service_page_url = get_permalink( $wbwss_general_settings['woo_sell_service_order_page'] );
}
$manage_order_url = esc_url(
	add_query_arg(
		array(
			'wss-itemid'  => $item_id,
			'wss-orderid' => $order->get_order_number(),
		),
		apply_filters( 'wss_services_page', $service_page_url )
	)
);
?>

<p><?php esc_html_e( 'You can check rejection cause and manage your order.', 'woo-sell-services' ); ?></p>

<p><a href="<?php echo esc_url( $manage_order_url ); ?>" class="woocommerce-MyAccount-downloads-file button alt"><?php esc_html_e( 'Manage Order', 'woo-sell-services' ); ?></a></p>
<?php

/**
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );
