<?php
/**
 * Customer submit requirement email
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/customer-submit-requirement.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see       https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates/Emails/HTML
 * @version 2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email ); ?>
<p>
	<?php
	/* translators: %s: Recipient Name. */
	printf( esc_html__( 'Dear %s,', 'woo-sell-services' ), esc_attr( $order->get_formatted_billing_full_name() ) );
	?>
</p>

<p>
	<?php
	/* translators: %1$1s: Order Number, %2$2s: Item id, %3$3s: Starting bold tag, %4$4s: Product name, %5$5s: Ending bold tag. */
	printf( esc_html__( 'This is a message regarding the order ( #%1$1s - %2$2s), %3$3s %4$4s %5$5s', 'woo-sell-services' ), esc_attr( $order->get_order_number() ), esc_attr( $item_id ), '<b><i>', esc_attr( $product->get_name() ), '</i></b>' );
	?>
</p>

<?php
$woo_author      = get_post( $product_id ); // Gets author from post.
$woo_author_id   = $woo_author->post_author;
$woo_author_data = get_userdata( $woo_author_id );
$woo_author_name = $woo_author_data->data->display_name;
?>
<p>
	<?php
	/* translators: %1$1s: Starting bold tag, %2$2s: Author name, %3$3s: Ending bold tag. */
	printf( esc_html__( 'Your seller %1$1s %2$2s %3$3s needs additional information to get started.', 'woo-sell-services' ), '<b>', esc_attr( $woo_author_name ), '</b>' );
	?>
</p>
<?php

	/* get services required data */
	$wbcom_wss_req_ques     = get_post_meta( $product_id, WOO_SELL_QUESTION, true );
	$wss_counter            = 1;
	$wbwss_general_settings = get_option( 'wbwss_general_settings', true );
	$service_page_url       = home_url( 'service' );
if ( isset( $wbwss_general_settings['woo_sell_service_order_page'] ) && '' != $wbwss_general_settings['woo_sell_service_order_page'] ) {
	$service_page_url = get_permalink( $wbwss_general_settings['woo_sell_service_order_page'] );
}
	$manage_order_url = esc_url(
		add_query_arg(
			array(
				'wss-itemid'  => $item_id,
				'wss-orderid' => $order->get_order_number(),
			),
			apply_filters( 'wss_services_page', $service_page_url )
		)
	);

	if ( ! empty( $wbcom_wss_req_ques ) && is_array( $wbcom_wss_req_ques ) ) :
		?>
	<div style="font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; margin-bottom: 40px;">
		<h2><?php esc_html_e( 'Requirement details', 'woo-sell-services' ); ?></h2>
	<ul>
		<?php foreach ( $wbcom_wss_req_ques as $key => $ques_info ) : ?>
		<li><strong><?php echo esc_attr( $wss_counter ) . '. ' . wp_kses_post( $ques_info['ques'] ); ?></strong></li>
				<?php
				$wss_counter++;
		endforeach;
		?>
	</ul>
	</div>
	<?php endif; ?>

<p>
<?php
/* translators: %1$1s: Starting bold and italic tag, %2$2s: Ending bold and italic tag. */
printf( esc_html__( 'Looking forward to provide you quality results. %1$1s All the best %2$2s.', 'woo-sell-services' ), '<b><i>', '</b></i>' );
?>
</p>

<p><a href="<?php echo esc_url( $manage_order_url ); ?>" class="woocommerce-MyAccount-downloads-file button alt"><?php esc_html_e( 'Provide Requirements', 'woo-sell-services' ); ?></a></p>

<?php
/**
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );
