<?php
/**
 * Order conversation emails between vendor and customer.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/customer-vendor-order-conversation.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see       https://docs.woocommerce.com/document/template-structure/
 * @author WooThemes
 * @package WooCommerce/Templates/Emails/HTML
 * @version 2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email );

$recipient_data = get_user_by( 'id', $recipient_id );
$recipient_name = $recipient_data->data->display_name;
$sender_data    = get_user_by( 'id', $sender_id );
$sender_name    = $sender_data->data->display_name;
?>
<p>
<?php
/* translators: %s: Recipient Name. */
printf( esc_html__( 'Dear %s,', 'woo-sell-services' ), esc_attr( $recipient_name ) );
?>
</p>

<p>
<?php
/* translators: %1$1s: Order Number, %2$2s: Item id, %3$3s: Starting bold tag, %4$4s: Product name, %5$5s: Ending bold tag. */
printf( esc_html__( 'This is a message regarding the order ( #%1$1s - %2$2s), %3$3s %4$4s %5$5s', 'woo-sell-services' ), esc_attr( $order->get_order_number() ), esc_attr( $item_id ), '<b><i>', esc_attr( $product->get_name() ), '</i></b>' );
?>
</p>

<p>
<?php
/* translators: %1$1s: Starting bold tag, %2$2s: Sender name, %3$3s: Ending bold tag. */
printf( esc_html__( 'Your have received a new message response from %1$1s %2$2s %3$3s.', 'woo-sell-services' ), '<b>', esc_attr( $sender_name ), '</b>' );
?>
</p>
<?php
$wbwss_general_settings = get_option( 'wbwss_general_settings', true );
$service_page_url       = home_url( 'service' );
if ( isset( $wbwss_general_settings['woo_sell_service_order_page'] ) && '' != $wbwss_general_settings['woo_sell_service_order_page'] ) {
	$service_page_url = get_permalink( $wbwss_general_settings['woo_sell_service_order_page'] );
}
	$manage_order_url = esc_url(
		add_query_arg(
			array(
				'wss-itemid'  => $item_id,
				'wss-orderid' => $order->get_order_number(),
			),
			apply_filters( 'wss_services_page', $service_page_url )
		)
	);
	?>
<p>
<?php
/* translators: %1$1s: Starting bold and italic tag, %2$2s: Ending bold and italic tag. */
printf( esc_html__( '%1$1s Looking forward to receive your response %2$2s.', 'woo-sell-services' ), '<b><i>', '</b></i>' );
?>
</p>
<p>
<a href="<?php echo esc_url( $manage_order_url ); ?>" class="woocommerce-MyAccount-downloads-file button alt">
<?php esc_html_e( 'Give Response', 'woo-sell-services' ); ?>
</a>
</p>
<?php
/**
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );
